@@ -18,41 +18,48 @@
 #ifndef PHRASEBOOKDIALOG_H
 #define PHRASEBOOKDIALOG_H
 
-#include <qbutton.h>
-#include <qradiobutton.h>
-#include <qbuttongroup.h>
-#include <qlabel.h>
-#include <qlistview.h> 
-#include <kmainwindow.h>
+#include <Qt3Support/Q3Button>
+#include <QtGui/QRadioButton>
+#include <Qt3Support/Q3ButtonGroup>
+#include <QtGui/QLabel>
+#include <Qt3Support/Q3ListView> 
+#include <QtCore/QList>
+#include <QtGui/QGridLayout>
+#include <QtGui/QDropEvent>
+#include <QtGui/QPrinter>
+
+#include <kxmlguiwindow.h>
 #include <klineedit.h>
-#include <kkeybutton.h>
+#include <kkeysequencewidget.h>
 #include <kurl.h>
 #include "phrasebook.h"
-#include "buttonboxui.h"
+#include "ui_buttonboxui.h"
+#include <kicon.h>
 
-class QListViewItem;
+class Q3ListViewItem;
 class PhraseTreeItem;
 class PhraseTree;
-class QStringList;
 class QString;
-class KListView;
+class K3ListView;
+class KToolBarPopupAction;
+class KActionMenu;
 
 struct StandardBook {
    QString name;
    QString path;
    QString filename;
 };
-typedef QValueList<StandardBook> StandardBookList;
+typedef QList<StandardBook> StandardBookList;
 
 /**The class PhraseTreeItem is an ListViewItem for either a phrase or a phrase book.
   *@author Gunnar Schmi Dt
   */
 
-class CheckBookItem : public QCheckListItem {
+class CheckBookItem : public Q3CheckListItem {
 public:
-   CheckBookItem (QListViewItem *parent, QListViewItem *last,
+   CheckBookItem (Q3ListViewItem *parent, Q3ListViewItem *last,
             const QString &text, const QString &name, const QString &filename);
-   CheckBookItem (QListView *parent, QListViewItem *last,
+   CheckBookItem (Q3ListView *parent, Q3ListViewItem *last,
             const QString &text, const QString &name, const QString &filename);
    ~CheckBookItem();
 
@@ -84,7 +91,7 @@ private:
    /** initializes the list of standard phrase books */
    void initStandardPhraseBooks ();
 
-   KListView *books;
+   K3ListView *books;
 };
 
 /**
@@ -95,25 +102,26 @@ private:
 class StandardPhraseBookInsertAction : public KAction {
    Q_OBJECT
 public:
-   StandardPhraseBookInsertAction (const KURL &url, const QString& name, const QObject* receiver, const char* slot, KActionCollection* parent)
-   : KAction (name, "phrasebook", 0, 0, 0, parent, 0) {
+   StandardPhraseBookInsertAction (const KUrl &url, const QString& name, const QObject* receiver, const char* slot, KActionCollection* parent)
+   : KAction (KIcon("phrasebook"), name, parent) {
       this->url = url;
-      connect (this, SIGNAL(slotActivated (const KURL &)), receiver, slot);
-   };
+      connect (this, SIGNAL(slotActivated (const KUrl &)), receiver, slot);
+      parent->addAction(name, this);
+   }
    ~StandardPhraseBookInsertAction () {
-   };
+   }
 
 public slots:
    void slotActivated () {
-      KAction::slotActivated();
+      trigger();
       emit slotActivated (url);
-   };
+   }
 
 signals:
-   void slotActivated (const KURL &url);
+   void slotActivated (const KUrl &url);
 
 private:
-   KURL url;
+   KUrl url;
 };
 
 /**
@@ -121,13 +129,13 @@ private:
  * edit window.
  * @author Gunnar Schmi Dt
  */
-class ButtonBoxWidget : public ButtonBoxUI {
+class ButtonBoxWidget : public QWidget, public Ui::ButtonBoxUI {
 public:
-   ButtonBoxWidget (QWidget *parent = 0, const char *name = 0);
+   explicit ButtonBoxWidget (QWidget *parent = 0, const char *name = 0);
    ~ButtonBoxWidget ();
 
-   KKeyButton *keyButton;
-   QButtonGroup *group;
+   KKeySequenceWidget *keyButton;
+   Q3ButtonGroup *group;
 
 protected:
    QGridLayout *keyButtonPlaceLayout;
@@ -138,7 +146,7 @@ protected:
  * @author Gunnar Schmi Dt
  */
 
-class PhraseBookDialog : public KMainWindow {
+class PhraseBookDialog : public KXmlGuiWindow {
    friend class InitialPhraseBookWidget;
    Q_OBJECT
 private:
@@ -168,7 +176,7 @@ public slots:
    void capturedShortcut (const KShortcut& cut);
    
    void selectionChanged ();
-   void contextMenuRequested(QListViewItem *, const QPoint &pos, int);
+   void contextMenuRequested(Q3ListViewItem *, const QPoint &pos, int);
 
    void slotRemove ();
    void slotCut ();
@@ -180,12 +188,12 @@ public slots:
 
    void slotSave ();
    void slotImportPhrasebook ();
-   void slotImportPhrasebook (const KURL &url);
+   void slotImportPhrasebook (const KUrl &url);
    void slotExportPhrasebook ();
    void slotPrint ();
 
-   void slotDropped (QDropEvent *e, QListViewItem *parent, QListViewItem *after);
-   void slotMoved (QListViewItem *item, QListViewItem *, QListViewItem *);
+   void slotDropped (QDropEvent *e, Q3ListViewItem *parent, Q3ListViewItem *after);
+   void slotMoved (Q3ListViewItem *item, Q3ListViewItem *, Q3ListViewItem *);
 
 signals:
    void phrasebookConfirmed (PhraseBook &book);
@@ -199,12 +207,12 @@ private:
    /** initializes the list of standard phrase books */
    void initStandardPhraseBooks ();
    
-   QListViewItem *addBook (QListViewItem *parent, QListViewItem *after, PhraseBook *book);
-   QListViewItem *addBook (QListViewItem *item, PhraseBook *book);
+   Q3ListViewItem *addBook (Q3ListViewItem *parent, Q3ListViewItem *after, PhraseBook *book);
+   Q3ListViewItem *addBook (Q3ListViewItem *item, PhraseBook *book);
    
    void setShortcut (const KShortcut &cut);
 
-   void _warning (const KKeySequence &cut, QString sAction, QString sTitle);
+   void _warning (const QKeySequence &cut, const QString &sAction, const QString &sTitle);
    
    bool isGlobalKeyPresent (const KShortcut& cut, bool warnUser);
    bool isPhraseKeyPresent (const KShortcut& cut, bool warnUser);
@@ -216,19 +224,22 @@ private:
    PhraseTree *treeView;
    ButtonBoxWidget *buttonBox;
 
-   KAction* fileNewPhrase;
-   KAction* fileNewBook;
-   KAction* fileSave;
-   KAction* fileImport;
+   QAction* fileNewPhrase;
+   QAction* fileNewBook;
+   QAction* fileSave;
+   QAction* fileImport;
    KToolBarPopupAction* toolbarImport;
    KActionMenu* fileImportStandardBook;
-   KAction* fileExport;
-   KAction* filePrint;
-   KAction* fileClose;
-   KAction* editCut;
-   KAction* editCopy;
-   KAction* editPaste;
-   KAction* editDelete;
+   QAction* fileExport;
+   QAction* filePrint;
+   QAction* fileClose;
+   QAction* editCut;
+   QAction* editCopy;
+   QAction* editPaste;
+   QAction* editDelete;
+
+   // Keep QPrinter so settings persist
+   QPrinter *printer;
 };
 
 #endif
